PusherMessage

Struct PusherMessage 

pub struct PusherMessage {
    pub event: Option<String>,
    pub channel: Option<String>,
    pub data: Option<MessageData>,
    pub name: Option<String>,
    pub user_id: Option<String>,
    pub tags: Option<BTreeMap<String, String>>,
    pub sequence: Option<u64>,
    pub conflation_key: Option<String>,
}

Fields

event: Option<String>channel: Option<String>data: Option<MessageData>name: Option<String>user_id: Option<String>tags: Option<BTreeMap<String, String>>

Tags for filtering - uses BTreeMap for deterministic serialization order which is required for delta compression to work correctly

sequence: Option<u64>

Delta compression sequence number for full messages

conflation_key: Option<String>

Delta compression conflation key for message grouping

Implementations

Source

impl PusherMessage

pub fn connection_established(socket_id: String, activity_timeout: u64) -> Self

pub fn subscription_succeeded( channel: String, presence_data: Option<PresenceData>, ) -> Self

pub fn error(code: u16, message: String, channel: Option<String>) -> Self

pub fn ping() -> Self

pub fn channel_event<S: Into<String>>(event: S, channel: S, data: Value) -> Self

pub fn member_added( channel: String, user_id: String, user_info: Option<Value>, ) -> Self

pub fn member_removed(channel: String, user_id: String) -> Self

pub fn pong() -> Self

pub fn channel_info( occupied: bool, subscription_count: Option<u64>, user_count: Option<u64>, cache_data: Option<(String, Duration)>, ) -> Value

pub fn channels_list(channels_info: AHashMap<String, Value>) -> Value

pub fn user_list(user_ids: Vec<String>) -> Value

pub fn batch_response(batch_info: Vec<Value>) -> Value

pub fn success_response() -> Value

pub fn watchlist_online_event(user_ids: Vec<String>) -> Self

pub fn watchlist_offline_event(user_ids: Vec<String>) -> Self

pub fn cache_miss_event(channel: String) -> Self

pub fn signin_success(user_data: String) -> Self

pub fn delta_message( channel: String, event: String, delta_base64: String, base_sequence: u32, target_sequence: u32, algorithm: &str, ) -> Self

Create a delta-compressed message

pub fn add_base_sequence(self, base_sequence: u32) -> Self

Add base sequence marker to a full message for delta tracking

pub fn delta_compression_enabled(default_algorithm: &str) -> Self

Create delta compression enabled confirmation